Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(449)

Unified Diff: third_party/WebKit/Source/modules/fetch/FetchResponseData.cpp

Issue 1857723002: Fetch: opaque redirect responses have a URL. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: this. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/fetch/FetchResponseData.cpp
diff --git a/third_party/WebKit/Source/modules/fetch/FetchResponseData.cpp b/third_party/WebKit/Source/modules/fetch/FetchResponseData.cpp
index afeca9ba07615f1f0baca2ead360b542d560e66c..567b3e5cd981722773a15aec18fb91140bd5a73f 100644
--- a/third_party/WebKit/Source/modules/fetch/FetchResponseData.cpp
+++ b/third_party/WebKit/Source/modules/fetch/FetchResponseData.cpp
@@ -116,8 +116,11 @@ FetchResponseData* FetchResponseData::createCORSFilteredResponse()
FetchResponseData* FetchResponseData::createOpaqueFilteredResponse()
{
// "An opaque filtered response is a filtered response whose type is
// |opaque|, status is 0, status message is the empty byte sequence, header
// list is an empty list, and body is null."
FetchResponseData* response = new FetchResponseData(OpaqueType, 0, "");
response->m_internalResponse = this;
return response;
@@ -125,11 +128,13 @@ FetchResponseData* FetchResponseData::createOpaqueFilteredResponse()
FetchResponseData* FetchResponseData::createOpaqueRedirectFilteredResponse()
{
- // "An opaque-redirect filtered response is a filtered response whose type
- // is |opaqueredirect|, status is 0, status message is the empty byte
- // sequence, header list is the empty list, body is null, and cache state is
- // |none|.
+ // "An opaque filtered response is a filtered response whose type is
+ // 'opaqueredirect', status is 0, status message is the empty byte sequence,
+ // header list is the empty list, body is null, and cache state is 'none'."
+ //
+ // https://fetch.spec.whatwg.org/#concept-filtered-response-opaque-redirect
FetchResponseData* response = new FetchResponseData(OpaqueRedirectType, 0, "");
+ response->m_url = m_url;
response->m_internalResponse = this;
return response;
}
@@ -116,8 +116,11 @@ FetchResponseData* FetchResponseData::createCORSFilteredResponse()
{
// "An opaque filtered response is a filtered response whose type is
- // |opaque|, status is 0, status message is the empty byte sequence, header
- // list is an empty list, and body is null."
+ // 'opaque', url list is the empty list, status is 0, status message is the
+ // empty byte sequence, header list is the empty list, body is null, and
+ // cache state is 'none'."
+ //
+ // https://fetch.spec.whatwg.org/#concept-filtered-response-opaque
FetchResponseData* response = new FetchResponseData(OpaqueType, 0, "");
response->m_internalResponse = this;

Powered by Google App Engine
This is Rietveld 408576698